CON
''==============================================================================
'' Example Spin program that uses the Toggle plugin. Since there is only one
'' plugin used in this example, all the registry initialization is performed
'' hera, and the plugin is set up and loaded, then the application code is
'' executed. In a program that needed to load multiple plugins, this would
'' usually be done in a separate "Initialization" object.
''==============================================================================

_CLKFREQ = 80_000_000
_CLKMODE = XTAL1 + PLL16X
_STACK   = 50

TOGGLE_PINS = $8000 ' pins to toggle by default (pin 15 is an LED on the C3)

OBJ
   Common : "Common.spin"
   Plugin : "Toggle_Plugin"
   Toggle : "Toggle_Layer3.spin"

PUB Start | ALLOC, Buffer

  '===================== REGISTRY AND PLUGIN SETUP =============================

  ' initialize the registry (must do this before loading any plugins)
  Common.InitializeRegistry
  
  ' Set up the Toggle plugin
  Plugin.Setup
  
  ' Start the Toggle plugin
  Plugin.Start

  '========================== REGISTER SERVICES ================================
  Toggle.RegisterServices
  
  '======================== EXAMPLE APPLICATION ================================

  ' retrieve the buffer space the Toggle plugin has been configured to use
  Buffer := Toggle.Get_Buffer

  ' set up the pins to toggle (we can change this dynamically)
  long[Buffer] := TOGGLE_PINS

  ' now toggle the pins at various rates, stopping between each rate change
   
  repeat

    ' toggle twice per second 
    Toggle.Set_Rate(CLKFREQ/2)
    Toggle.Start_Toggle
    ' wait for a few seconds
    WAITCNT(cnt + CLKFREQ*9/2)

    ' stop for a second 
    Toggle.Stop_Toggle
    WAITCNT(cnt + CLKFREQ)

    ' toggle ten times per second 
    Toggle.Set_Rate(CLKFREQ/10)
    Toggle.Start_Toggle
    ' wait for a few seconds
    WAITCNT(cnt + CLKFREQ*9/2)
   
    ' stop for a second 
    Toggle.Stop_Toggle
    WAITCNT(cnt + CLKFREQ)
